from component import Component

class WebMarkupContainer(Component):
    """
    In Wicket, this class exists primarily to be a non-abstract Component
    that can be used in page hierarchies; I haven't yet encountered any behaviour
    of its own, so it's questionable whether this class should even be included
    in smoff at this time.
    """
    pass
    